cppcheckROutput and render functions for using cppcheckR within
Shiny applications and interactive Rmd documents.
cppcheckROutput(outputId, width = "100%", height = "400px")renderCppcheckR(expr, env = parent.frame(), quoted = FALSE)
output variable to read from
a valid CSS unit (like "100%",
"400px", "auto") or a number, which will be coerced to a
string and have "px" appended
an expression that generates a 'cppcheckR' widget
the environment in which to evaluate expr
logical, whether expr is a quoted expression (with
quote())
cppcheckROutput returns an output element that can be
included in a Shiny UI definition, and renderCppcheckRR returns a
shiny.render.function object that can be included in a Shiny server
definition.